channels = ['@ukrultras', '@aeroplaneta', '@GadgetsForSale', '@MaksPodzigun', '@hmarochos', '@SerialList', '@kolhumor',
             '@dekanat_fmm', '@ukrtour', '@mudrost_mem', '@UkrMemesmineproblemes', '@infOdessa', '@ain_ua_tg',
             '@oltsyaka', '@lowcostua', '@KaterynaZoryana', '@znoonaa200', '@kinoman_ua', '@tourstanok_UA',
             '@rozetka_travel', '@klekscourses', '@shedevryreklamy', '@odessitua_com', '@TL_news', '@inlvivinua',
             '@navtg', '@osssumdu', '@aquotes', '@esportsua', '@jopnuta_podruga', '@IF112', '@itkpi', '@TravelTango',
             '@bikeua2eu', '@acmodasi_ua', '@YaKurkul', '@SBUkr', '@joinNBU', '@trubuprorvalo', '@shosneto',
             '@uacosmos', '@agrotax', '@traktoristua', '@atlasweekend', '@crazybeeua', '@vncomua', '@cultureznu',
             '@pidsluhano_ukraine_ua', '@ua_covid_19_ua', '@black_gymor', '@historydayua', '@ubereatsua', '@ziznanya',
             '@ukrlit', '@bedeveloped', '@novytv', '@dw_travel', '@hochu_v_kpi', '@illienko', '@spuf_knu', '@CustomsUA',
             '@dumkyprovazhlyve', '@glubinaz', '@eduhubinua', '@vinlife24', '@gastroprikhozhane', '@spravagromad',
             '@developmentbooks', '@happymonday', '@ticketsbox', '@MiComUA', '@Stankokulemet', '@travelsInfo',
             '@pr_perfect', '@nulp_prepod', '@HORECA_DNEPR_RABOTA', '@Ags_Donbass', '@med3pediatricians',
             '@ukrpravda_news', '@virsholub', '@Konstlaw', '@ikitb', '@paliturk', '@pmkagency', '@psyhologya_zhyttya',
             '@PM_Shmigal', '@chanel24', '@promandry', '@zno_ukr', '@myvolia', '@prometheusmooc', '@KanalSmihu',
             '@pani_vchytelka', '@sobakam', '@superagronomcom', '@mainacademy', '@samburska_giveaway', '@tusamyaso',
             '@box_of_pandora', '@anecdotes_ua', '@poltavanovosti', '@offer_blockchain', '@lab_of_childhood',
             '@taka_polsha', '@marusyazvirobiy', '@knteu_vstup', '@brodetsky_2', '@Triukhan', '@pavlovdrop',
             '@ukrzaliznica', '@telegrafdesign', '@GolosZmin', '@istukrmemes', '@vkadr', '@nmu_file_zanuch',
             '@Poltava_live', '@memasy_dlya_masy', '@ukr_poll', '@LvivMisto', '@cool_advice', '@GreenSommelier',
             '@zhuk_ua', '@gurt11', '@uasukr', '@dkkadrovikua', '@politicusvulgaris', '@americaua',
             '@Deutsche_Sprechweise', '@allonews', '@open_ukraine', '@christiansua', '@dcpgodmemes', '@kyivpatrol',
             '@Finance_ukr', '@VolunteerCountry', '@cargo1_auto_from_usa', '@scistudsoc', '@ukr_culinar',
             '@starapoltava', '@Football_Transfery', '@vzapertiua', '@dou_odesa', '@baptistyouthua',
             '@football_and_more', '@FashionUkraine', '@virshi_ukr', '@iod_media', '@Your_TURN', '@jerryheil',
             '@turizmua', '@kyivworkz', '@zhdanovadropshipping', '@usionline', '@AnimeKultura', '@koronavirus_news_ua',
             '@baldtrue', '@ukr_artists', '@orestzub', '@dmytro_dubilet', '@V_N_ZHEREBNIUK_DECEBAL', '@studlava',
             '@svstn', '@zakupki_prom_ua', '@vstuposvita', '@kpi_666', '@Moviestape', '@Chernigov_ua', '@Konkretyka',
             '@SnowDeal', '@profkomkarazina', '@prostirua', '@m_y_day', '@studwaydiem', '@IT_v_UA', '@nightflow',
             '@uceqa', '@opendataukraine', '@easyxpress', '@fyouall', '@thebig4', '@ukrainskinovosti', '@psagentclub',
             '@ear_on', '@g_untitled', '@authors_anonymous', '@sharaievskyimarketing', '@VolodymyrAriev', '@platinaKPI',
             '@ridna_ua', '@justbus', '@mdfashionua', '@ikrus', '@textyorgua', '@studway', '@afishaskidok',
             '@taburetkax', '@tourstanok_Lviv', '@zakononline2019', '@UkropInfo', '@linuvuyblog', '@sraka_motyka',
             '@mistotravel', '@pbikni', '@cxemu', '@novinach', '@yaizakon', '@zekharkiv2019', '@franchua',
             '@iamgoodatlviv', '@deshevihoteli', '@ukrainanovosti', '@dtp18plus', '@rabota_work_ua', '@fri_ua',
             '@megogolive_ua', '@dmytro_karpov', '@emailingskills', '@mistoMarii', '@poltavtsev01', '@hyperthelia',
             '@dragomanivtsi_FPP', '@lyapotagoods', '@goodnewsforyou', '@nlu_live', '@yourchurchill', '@FedorivHub',
             '@artius_law_firm', '@higherspro', '@PriceTimeBest', '@interesting_all', '@TCH_channel', '@kpi_trade',
             '@rooms_lviv', '@sportlife_ua_official', '@zapas_slv', '@StudentWanted', '@solovei_ihor',
             '@englishdictionaryua', '@posad_kh', '@medicinainfo', '@kpi_look', '@beinprogress', '@lifecell_campus',
             '@uaAutoNews', '@AlonaShkrum', '@dmelomaniya', '@politmedia22', '@jccnaukma', '@esnkyiv', '@brokers_diary',
             '@remote_work_ua', '@footboomcom', '@znoua1', '@watsonsukraine', '@ukrainian_map', '@operativeukr',
             '@mvs_ukraine', '@zhatkz', '@kermoua', '@your_chance_ua', '@memolanka', '@vybir_profesii', '@xchernivtsi',
             '@ukrzoloto', '@upc_news', '@dekanat_fel', '@dekanatfsp', '@suspilnekherson', '@ragoolee', '@uvidpustku',
             '@smachni_retsepty', '@cyberknu', '@pimpENgUA', '@marliua', '@ukr_lawyer', '@pskpi', '@alfabankua',
             '@docsm', '@chytalka', '@impulse_ukr', '@rivne1tv', '@bezocinok', '@InfoResist', '@KarandashUA',
             '@jb_girls', '@films_radnik', '@rozumschoolgeo', '@ZeRada1', '@thebabel', '@agrorobota_agrokholdynhy',
             '@strichka_ua', '@uabrand', '@magellanuz', '@minimalka', '@karpliukV', '@Shaleniy_Kit', '@NIZHN0',
             '@lnuvmb', '@uafootballcom', '@fat_zero', '@atyznaw', '@stepbystepfluency', '@Instahusband',
             '@legalhub_online', '@taras_shevchenko', '@ukr_opros', '@zvyk_ua', '@ua_danylo', '@mikrozaim_ua',
             '@odessaopt7km', '@TimeToTravel', '@drive_pdr_znay', '@gomolod', '@watchingua', '@NPUgurt',
             '@hromadske_ua', '@postironichniymetamodern', '@artehvact', '@superskidki_ua', '@podslyshenopolice',
             '@agrorobota_kyiv', '@mozofficial', '@pogodaUnian', '@opentv_media', '@map_stat_dat', '@istzno',
             '@placeforgirls', '@Ukr_lit_ZNOcloud', '@anime_pro', '@BusinessOpportunitiesKyiv', '@kyiv_with_kids',
             '@kvashnevskyiFM', '@SaleClubUkraine', '@mouselab', '@OnlineUkraine', '@histph', '@vantazhivka', '@ITCUA',
             '@nach_shtabu', '@ternopilwork', '@tv7mrpl', '@ukr_armed_forces', '@OstanniyCapitalist', '@RBC_ua_news',
             '@lanetua', '@automarket_ua', '@EnglishPremierLeagu', '@kkchannel79', '@darkside_ami', '@chernigovnovosti',
             '@belka_space', '@Koronavirus_info_moz', '@t_oday', '@houseofeurope', '@lingvaskills', '@bdisKNU',
             '@allNMU', '@bioblogic', '@philiszanka', '@teleobuh', '@severodonetsk', '@underrrcoverrr', '@econom_notes',
             '@bluzka_ua', '@lubeavtokhm', '@polkazov', '@uapentecostal', '@viktoRRocha', '@novrek', '@AgroPolitCom',
             '@malevych', '@Ukrainian_language', '@trclubava', '@agrorobota_trading', '@luxoptica_ua', '@poltava_to',
             '@FAKTY_ICTV', '@avramenko_chanel', '@Dreyph', '@ukrapmemes', '@orden83', '@carpaty', '@kyivosvita',
             '@backpackersua', '@lviv_it', '@Bandershtatfest', '@thelnu', '@space_job', '@WikiUa', '@aviasales_ua',
             '@brother_junior', '@blyadskiy_kharkov', '@cheaptripnow', '@AliExpress_do10', '@popkornua', '@tuiua',
             '@wtfbit', '@kino_divan', '@hardsmoke', '@snuwixgovno', '@ze_english', '@Ukranian_News', '@elucidation_gw',
             '@ukr_mova', '@theGAMEua', '@SportsHealthUa', '@nubip1898', '@AMB_islnd', '@oficialvmr', '@NikArtshoes',
             '@fainaFrancia', '@medic_ua', '@vnlviv', '@prykoly_ua', '@Vinnitsia_ua', '@kyivconcert', '@ua112',
             '@slavinska_reads', '@UkrFin', '@zaichenkoteam', '@BeerMarketUkraine', '@OnePlusOneChannel', '@pingvinpro',
             '@MilingoJournalUA', '@discover_ukraine', '@PDRUA', '@telegra4chukr', '@TheMensHealth', '@NASS_of_ART',
             '@zaxidfest', '@novostyukraine', '@drinkery_ukraine', '@lessmess', '@ukr2eng', '@ilonkis_z', '@offer_ua',
             '@utlgr', '@dniprofilm', '@smokesomile', '@Kyiv_Live', '@Lv1256', '@themanagerblog', '@karazinuniver1804',
             '@technologiiua', '@Afisha_odessaua', '@ZNlife', '@vso_ukr', '@JYSK_ua', '@chemood_tour',
             '@MOZ_Ukraine_official', '@the_old_chest', '@censor_net', '@osnovamaibutnoho', '@hotlinefinance',
             '@zedigital', '@geographia_znocloud', '@nauhub', '@presinfokpi', '@ngo_insight', '@pictureshistory',
             '@SharkCo', '@kpi_work', '@iplanua', '@odessaligasmeha', '@forbes_UAA', '@olkom_home',
             '@orjeunesseofficial', '@PokemonGOnewsUKR', '@if1711', '@sriblotroyandy', '@bykvu', '@DynamoK',
             '@top1top10', '@conservatorjournal', '@HoReCa_Premium', '@galkaifuanews', '@Ukr_mova_ZNOcloud',
             '@mikhaildobkin', '@progressevi', '@ukrmovafi', '@ua_kataloge_oriflame', '@MyLifeinukraine', '@novyny',
             '@lavinamallua', '@nationalcorps', '@kgbfiles', '@ua_hottours', '@profkom_nau', '@cybervacancies',
             '@visnyk_ua', '@krasa_Vn', '@studtravel', '@businessweekua', '@nighthistory', '@oneplusonevideo',
             '@off_the_record', '@Sho_Tama', '@KyivOperativ', '@ZeFuckTy', '@ty_vdoma', '@uamfa', '@korisno',
             '@eventskyiv', '@novoe_vremya', '@slovo_dnya_ukr', '@vmiske', '@elitnews', '@voxcheck', '@kyiv_meet',
             '@smartan', '@uacatalog', '@Leadershipforyou', '@dailymetal', '@kpitv', '@audiounn', '@chomu_tse_tak',
             '@insta_icon', '@dnepr_ladies', '@metrainee', '@promocode_ua', '@iventKHM', '@cowoguru', '@english_ukr',
             '@eventlviv', '@sunvery_recruiting', '@radio_kottans', '@uacomics', '@chernivtsigram', '@ua_vd_i_vn',
             '@uanother', '@sr_kpi', '@tasty_flashbacks', '@kinchik_pid_vinchik', '@golovaOP', '@agrosem_ua',
             '@starlev', '@nbdwn', '@ukrlit_mems', '@Metro6', '@donetsk_kurs', '@KIVAERO', '@pnulife', '@league_uba',
             '@vidpoviday', '@kpi_777', '@znohistoryua200', '@VR_UA', '@stas_memes', '@naplanetikino', '@ukrarticles',
             '@ubaua', '@odeparh', '@revdiachannel', '@DesJobUa', '@skyfreechannel', '@cheap_europe', '@lvivjob',
             '@hovoryt_Ukraina', '@timetocook', '@juggua', '@LvMedBr', '@catars_is', '@BeeGranola', '@lLKH_HH',
             '@shiftua', '@Black_water_division', '@Coronavirus_Info_MFA', '@KP_KMR_IS', '@hellokyiv', '@non_fikshn',
             '@UkraineHack', '@NAZK_gov_ua', '@ukrtgcatalog', '@studcouch', '@cybercalm', '@kyiv_traffic',
             '@KPMG_Ukraine', '@nakipelovo', '@cikavisko', '@vasyl_kit', '@coronaviruscomua', '@nails_ua', '@kma_today',
             '@PresidentZelenskij', '@you_can_know_more', '@guliajpole', '@andriysadovyi', '@beloesuhoeUA', '@KastaUa',
             '@englishwordsua', '@ilioutfit', '@wasmedia_ua', '@xaxaua', '@zhpmch', '@UaSportTV', '@osvitanova',
             '@XTOTAM', '@journaltg', '@naurok', '@Ukrainska_Mova', '@junior_dou_ua', '@buddynaukma', '@Dnepr311',
             '@osoblyva', '@zapas_slvEN', '@yakabooua', '@dnvr_31', '@regionality', '@math_znocloub', '@tripmix',
             '@faini_memes', '@vonyporuch', '@ukrainiantraveler', '@the_ukr_news', '@Medvezhatko1488', '@commonscomua',
             '@ternopil1540', '@po_secretyy', '@AlleeECHR', '@desibuy', '@iptkpiguild', '@clockwork_88', '@nails_manik',
             '@commacomua', '@milabaraeva', '@mintsyfra', '@aliexpresukraine', '@lvivVScoronavirus', '@dou_editors',
             '@apkha', '@avto_kh', '@valizakordon', '@KievG', '@manifestinua', '@FootballUK', '@moviesjournal',
             '@noski_ua', '@skaybu', '@nkplusua', '@nacionalist_ua', '@elmundochannel', '@int_planet', '@Hotels24_ua',
             '@KarantynKyiv', '@villageua', '@slovopro', '@top_photo', '@varianty_lviv', '@dietologua',
             '@oblradadnipro', '@npzbvnkngchtn', '@nauinformal', '@vse_pro_vse_ua', '@SlugaNarodu_Official',
             '@lifeandlies', '@topfilms_ua', '@theytoldme', '@cresume', '@prodesign_in_ua', '@brutfoot', '@fmc_ua',
             '@leport', '@Metalist1925_uffs', '@ukrexcerption', '@autokiev', '@shom_oratoryschool', '@Bukovel_Live',
             '@officialeurosolidarity', '@qoutefilms_ua', '@kpi_hostel8', '@kliati_pereklady', '@kpi_fea',
             '@reklama_lviv_ua', '@dekanat_fpm', '@StudHurtDnipra', '@Chtec_ua', '@esportinua', '@ze_team2019',
             '@Velo_kyiv_rides', '@vnugo', '@kniazevych', '@myalgorhythm', '@klounnnnn',
             '@DonbassYasinovatayanaliniiOgnia', '@bbc_ukr', '@vox_ukraine', '@nov1ny_sv1ty', '@knutkt', '@kpi_library',
             '@cucumberapps', '@NK_support', '@vinnytsiaVScoronavirys', '@Porohobotchenko', '@banderamedia',
             '@smartuseronline', '@NG_promotion', '@budmaster_info', '@natsionalKharkiv', '@andriykovi',
             '@zentropa_ukraine', '@mandruy', '@hypermuseum', '@ZhmerPegas', '@digitalkrasa', '@tekso_mood',
             '@upravlinniamolodi', '@aventour_ua', '@robotavidtata', '@playua', '@dou_vinnytsia', '@rentCV',
             '@ukrnastup', '@chesno_vybory', '@torontotv', '@ukrgram', '@JoinUPHT', '@startupcontent', '@pohrib',
             '@yyluchkiv8blog', '@ukrainetv', '@nlo_tv', '@fastnews_ua', '@zik_ua', '@fairytailss', '@Krosogolik',
             '@allgolobutsky', '@vata_show', '@shopzona', '@yarmakandriy', '@ukrazom_org', '@kpiquotes',
             '@kpi_hostel18', '@coronews', '@open_kmbs', '@omriyana', '@exchanger_ua', '@ingeniusua', '@guli_vyshnya',
             '@takavacoffeebuffet', '@ua_ternopil', '@andrey_burenok', '@kinopodgon1', '@ukrain1an_news',
             '@kpi_hostel20', '@cinema_room', '@frankivskcity', '@LastBP', '@Koronavirus_kharkov', '@tickets_ua',
             '@theKIEF', '@espresotb', '@ZNO_Grant_education', '@slukhachua', '@mm_knu', '@kyivmetroalerts', '@factuu',
             '@goryshche', '@footballhubua', '@infeach', '@usedappleua', '@founder_Co', '@ukraina24tv', '@friendsua',
             '@news19cov', '@siryivovk', '@unitcity', '@mixsport_pro', '@docua', '@HR_Kiev_UA', '@pelekh', '@dropgv',
             '@correctariumukr', '@LetsGoHike', '@podiilviv', '@studyhardIT', '@cp_km', '@paniukraine', '@silposilpo',
             '@Kiev_job', '@volunesians_ukraine', '@work_eu', '@citrus_academy', '@ekipazh_svobody', '@havryliakonair',
             '@agroportalua', '@moz_official_koronavirus', '@datarootlabs', '@kursvalutkiev', '@fainakraina',
             '@legio_historica', '@YZSPzashita', '@uabash', '@kraina_ua', '@ukrpayless', '@comfysale', '@boontivnyk',
             '@politoscope', '@oburay', '@osoblyve', '@events_ua', '@Dumskaya', '@loveandbudget', '@tm_ukraine',
             '@Miroslavhai', '@sxodim_Kiev', '@dylema', '@bf_109e', '@nashformat', '@ukraineneveragain', '@eventDP',
             '@volkstum', '@accemedin', '@zabutiphoto', '@mov_tribunal', '@smart_videos_ua', '@police_ua',
             '@KievEventsToday', '@judicial_practice', '@dou_kyiv', '@cho_english', '@typical_journalists',
             '@DynamoKyiv', '@ua_bizidea', '@detector_media', '@milinua', '@technpage', '@fin_day', '@bodybuildingfor',
             '@fin_support', '@top_cars_ua', '@history_ukrfacts', '@pinteresttrends', '@startsomethingnow',
             '@animemes_ua', '@politarenainfo', '@cs_100', '@kudakyiv', '@FemidaLaw', '@tsnua_blogs', '@nulp_memes',
             '@lfyoulviv', '@radiotrek', '@osvitatopnews', '@favbetofficial', '@redactionodua', '@SaleeUA',
             '@kato_garbage', '@appleforcedrop', '@dilovodstvomrpl', '@myimoz', '@LowCostTravel_1001idea',
             '@fishingsecret', '@Stud2work', '@supremecourtua', '@topuanews', '@rektorguberski',
             '@Promocodi_akcii_lviv', '@vovkst', '@estetuka', '@FiFishki', '@pashabroskii', '@lift_ua', '@recordsua',
             '@lvivmodelka', '@prohow_digital', '@samovdoskonalennia', '@horeca_lvivska', '@donorua', '@ukrainer_net',
             '@kneulive', '@lvivcitystandup', '@ua_ultras', '@englishkiev', '@nynipro', '@hot_eng', '@Helpremont_in_ua',
             '@svato_ua', '@Gramotaua', '@dekanat_fiot', '@futuretodayua', '@kinoukrr', '@rishuchireformy',
             '@youcontrolnews', '@minfin_realty', '@reklamnutuy', '@cld_nlu', '@nivki_park', '@neymovirno',
             '@devo4ki_takie_devo4ki', '@mistoxa', '@global_events', '@pocketbookua', '@vseosvita', '@uavisualinfo',
             '@svoboda_radio', '@nubipnules', '@Oleksiy_Honcharuk', '@ukrlib', '@nachasi_com', '@tapit', '@kinoriumUA',
             '@COVID19_Ukraine', '@channel_ua', '@who_europe', '@milanabet1', '@slidstvo_info', '@chasopys',
             '@svitolina', '@StudNaUKMA', '@mosiychuk72', '@programist_ua', '@poyasnyzaartua', '@odessa_kurs',
             '@prikollikes', '@tvoya_psychology_UA', '@V_Zelenskiy_official', '@tvoysohranenki', '@YoungUncorrupt',
             '@hungrykyiv', '@mindua', '@dtkt_ua', '@ist_znocloud', '@solovina', '@jobknu', '@KEF_by',
             '@green_way_com_ua', '@freebooks_ua', '@mebleva_kimnata', '@kpi_xtf', '@scout_dancers_and_models',
             '@zakopejku', '@Motivaciy', '@bizcensor', '@FinClub_ua', '@mentoltea', '@nigtiUA', '@seelifecv',
             '@ukraine_novosti', '@automobilusa', '@nlu_info', '@skido4nik_travel', '@UITua', '@shtravelagency',
             '@thegeeklounge', '@oldyorktimes', '@ukraine_to_nato', '@innowade_marketing', '@krot_1',
             '@yobnunytyy_english', '@parfumsua', '@nowasteukraine', '@karpatylviv', '@dsgnbr', '@notes_christian',
             '@pelenio', '@youmammal', '@smachnoukr', '@design_18', '@spu_knu', '@yurgazeta', '@nabudaily',
             '@polcringe', '@knuevents', '@znua_live', '@yourexua', '@TseHUB', '@ukrazom', '@lifetotravel',
             '@ZKraiuVKrai', '@ntudp', '@vgorode_odessa', '@ukrinform_news', '@MediaLab_Online', '@yuzhva', '@vezuvii',
             '@aschotamupp', '@slovaua', '@freikorps_org', '@business_ukraine', '@ukrfootball_tg', '@zdaiblood',
             '@lowcostavia_travel', '@taxincognito', '@kinobazza', '@diia_gov', '@dzerkalomedia', '@akkermanvasya',
             '@fruty_jigit', '@UCUadmission', '@afisha_u_Lvovi', '@podiilist', '@ukrmems', '@cheaptr_p', '@Ironvoter',
             '@zno_natali', '@marketing_without', '@intromen', '@robotaBC', '@mojamova', '@ucoffee_family',
             '@lifecellukraine', '@fly_UIA', '@mayak_odessa', '@agronews', '@vezhakpi', '@izotope', '@whataflight',
             '@detaliweare', '@pvp_0532', '@rozumschoolua', '@podorozhuy', '@obozrevatelsport', '@lviving',
             '@okwine_ua', '@romabroma', '@dneprnews', '@IASA_Student_Council', '@textbook_ua', '@workuamedia',
             '@UAmonogram', '@Concertua', '@UAtaxesYou', '@DavayLowcostInfo', '@veresclub', '@OpendatabotChannel',
             '@businesseventskyiv', '@jobslviv', '@studydive', '@wlb_gl', '@nerdgasm', '@warmtours', '@aviamarket',
             '@september', '@imthebatya', '@pogana', '@ukr_businessman', '@suspilnerivne', '@MUKGroup', '@navsi200',
             '@Kyiv_Lifestyle', '@ibelieve_ua', '@YeRobotaIF', '@lowcostavia', '@vichirniykyiv', '@poradnyk',
             '@nmu_dopomoga', '@bestkyiv', '@rooms_kyiv', '@nabolelo_odessa', '@bezviztravel', '@Z_Aliexpress',
             '@kyivmaps', '@numstation', '@newssumy', '@npuFSIO', '@samsungukr', '@ryanairnews', '@pingvinpro_news',
             '@ua_rozvynuta', '@Cherkasy_ua', '@mind_live', '@teterivonelove', '@uifuture', '@sharij_odessa',
             '@kyivtrash', '@fabrika_kherson', '@tvoyamova', '@bukovel_resort', '@artylkiev', '@gifsfit',
             '@golda_meir_ukraine', '@project_juventa', '@etiketua', '@m1stud', '@irpininteresting', '@gazetaua_news',
             '@BestSalesKiev', '@tcn_ua', '@podslushano_kpop_ua', '@plomin', '@tuiukraine', '@knuboard',
             '@ukr_mova_online', '@ednist', '@ua_meteo', '@sarcazm_tg', '@kpi_fmm', '@LBuanews',
             '@national_aviation_university', '@thebuchacity', '@tsurv', '@svmotorss', '@lawandevents',
             '@ua_coronavirus', '@localkawo', '@kristinahomenko', '@kryivka', '@ZnoUkr_mova', '@churcher_info',
             '@sobersthoughts', '@morgenxshtern', '@makeyourmind', '@TatoVlog', '@COVlD19_Ukraine', '@agrokebety',
             '@dekanat_mmi', '@ok_spn', '@healthyukraine', '@innovativeplums', '@korrespondentnet', '@rozumets',
             '@dnrpofitsial', '@tginua', '@networkingukraine', '@STUDPOINT', '@OP_UA', '@angelinatroyann', '@lunoteka',
             '@dou_kharkiv', '@mandrivnukposvity', '@schebetyk', '@bazaavtonomerov', '@fourTvComUa', '@uafukraine',
             '@archi_gid_ua', '@chesno_movement', '@primat_kpi', '@Malaahit', '@dekanat_ipsa', '@tiahnybok',
             '@samonerozvytok', '@OriflameUkraine', '@italian_online_in_ua', '@dekanat_fti', '@comfygame', '@SkrypinUA',
             '@adventistyouth', '@ShakhtarD', '@srs_knu', '@bossautoukraine', '@militaryhonor', '@kyivsmartcity',
             '@fashionukr', '@theinsider_ua', '@agrorobota_roslynnytstvo', '@uareview', '@digital_jam',
             '@psyhokorobochka', '@steptv', '@zabava_lviv', '@coronavirus_in_ukraine', '@greenforestschool',
             '@studradaONU', '@ua_fact', '@amoregram', '@PodcastsNOWua', '@bezbroni', '@antikor', '@postironicpol',
             '@ucatua', '@iniazkaraga', '@ukr_pravda', '@vanilla_ua', '@orendalvivn', '@football_ukrain',
             '@FootballPortalNews', '@slukh', '@tokar_ua', '@veter_doit', '@tochkadonbassa', '@filmuagroup',
             '@inbookwetrust', '@odessanovosti', '@postironia_politologia', '@waveua', '@mykharkov_info',
             '@dynamo_news_1927', '@dumyua', '@afishakieva', '@electronics_cs', '@rootsmusic', '@cheapflightsukr',
             '@ulpra', '@curlymovies', '@kpicampus', '@Shmygal_pm', '@martsinkiv_ONLINE', '@ziznannia', '@hroshiua',
             '@EdYurchenko', '@GenuineLeatherOnly', '@marzandpanna', '@easypeasykyiv', '@epamuniprogua', '@kpi_lampa',
             '@ukrbotbot', '@anonchatua', '@dou_lviv', '@breakingnews_ukraine', '@kucherkh', '@konkurentinua',
             '@studparlament_IJ', '@tripmydream_tours_ua', '@Gastroli_News', '@ChernihivOperative', '@StudProfkomONU',
             '@faktylive', '@culinaracademy', '@rabota_ukraina', '@bbcukrainian', '@groshi24', '@cvjobs',
             '@politeyes_rada', '@fisitchan', '@dou_kyiv_events', '@transport_dp', '@TEDinfo', '@lex_info',
             '@biologia_znocloub', '@rivneshtirlits', '@oratorknu', '@dou_dnipro', '@krutoznavstvo', '@BibleQuest',
             '@unicorn_promocodes', '@jobnuta', '@discoutns_UA', '@kriskosyk', '@advocat_ua', '@kyivnochnoy',
             '@rabota_brovary', '@purplesapiens', '@gradusadparnassum', '@ukuderground', '@vyconavec', '@kyivoda',
             '@bavky', '@hdln24', '@interbuh_lz', '@suspilnenews', '@amnesiascope', '@l1shop', '@krasa_Lv',
             '@smolii_ukraine', '@ternopiljob', '@igrosho', '@frazeolohizmy', '@abookua', '@mandrui_ukrainoyu',
             '@sherlockRV', '@pz_zntu', '@MotoristUA', '@hromadskekharkiv', '@icreateinukraine', '@BILL_KNU', '@bitua',
             '@confainua', '@vntu_live', '@apriori_edu', '@SolovinaMova', '@auto_volt', '@L7Trade_Ua', '@ogaeukraine',
             '@PresidentPoroshenko', '@iplankids', '@kitnadroti', '@primetimemagazine', '@UAchannels']
